#!/bin/sh
#
# File:		AppNamePLUSinstall_after.sh
#
# Product:	Tivoli Module
# Description:	Shell Script
# Author:		Module Generator
#
# Generated:	
#
# (C) COPYRIGHT Tivoli Systems, Inc., 1997
# All Rights Reserved
# Licensed Material - Property of Tivoli Systems, Inc.
#
MODULE_VERSION=;export MODULE_VERSION

#
#	The standard directory and the /Plus override script
#
ETC=/etc/Tivoli
SCRIPT=PLUSsetup_env.sh

#
#	If this is NT, then etc is in a different location
#
if [ x\"$OS\" = x\"Windows_NT\" ] ; then
     ETC=$SystemRoot/system32/drivers/etc/Tivoli
fi

#
#	Look for our override script, if not there, then use the
#		standard one.
#
if [ ! -f $ETC/$SCRIPT ]; then
	SCRIPT=setup_env.sh
fi

. $ETC/$SCRIPT


#
#	Set up some popular environment variables.
#
OSERV=`objcall 0.0.0 get_oserv`
export OSERV
INST_DIR=`objcall $OSERV query install_dir`
INST_DIR=`echo $INST_DIR | tr "\\\\\\\\" "/"`
export INST_DIR
REGION=`objcall $OSERV query whoami | awk '{print $1}'`

LIBRARY=`wlookup Library`

#
#	Get the region name to avoid collisions
#
IRO=`wlookup InterRegion`
IRONAME=`idlattr -t -g $IRO name string`
IRONAME=`eval echo $IRONAME`

DEFSEN=\"TivoliSentryDefaults#$IRONAME\"

MNOID=`objcall 0.0.0 get_host_location`
eval MNNAME=`idlattr -t -g $MNOID label string`
export MNNAME

#
#       Process winstall variables 
#
ALL=false; REGION_ONLY=false; UNDO=false; COPY_FILES_ONLY=false; UNDO_INFRA=false
DO_JOBS=false; DO_FILEPACKS=false; DO_SENTRIES=false

UNINSTALL=${UNINSTALL-0}
UNDO=false
UNINSTALL_OPTS=""

if [ $UNINSTALL -eq 1 ]; then
  UNDO=true
  UNINSTALL_OPTS=""
fi

## cue off DOTASKS from winstall being either "0" or "1" to know
## if we're in incremental install mode ...
if [ "$DOTASKS" ]; then
  INCREMENTAL_INSTALL=true
  if [ $DOALL -eq 1 ]; then
    ALL=true
    UNINSTALL_OPTS="a"
  fi
else
  INCREMENTAL_INSTALL=false
  ALL=true
fi

if [ "$ALL" = false ]; then
  if [ $DOTASKS -eq 1 ]; then
    DO_JOBS=true
    UNINSTALL_OPTS="j${UNINSTALL_OPTS}"
  fi
  if [ $DOMONS -eq 1 ]; then
    DO_SENTRIES=true
    UNINSTALL_OPTS="s${UNINSTALL_OPTS}"
  fi
  if [ $DOFPS -eq 1 ]; then
    DO_FILEPACKS=true
    UNINSTALL_OPTS="f${UNINSTALL_OPTS}"
  fi
fi

export INCREMENTAL_INSTALL ALL DO_JOBS DO_SENTRIES DO_FILEPACKS UNDO

PLUSDIR=$INST_DIR/generic_unix/TME/PLUS
LINKDIR=$PLUSDIR/LINK
PRODDIR=$PLUSDIR/SECUREWAY_FIREWALL
PATH=$LINKDIR:$PRODDIR:$PATH
export PATH

cd $PRODDIR

. ./PLUSproduct-info.sh

#
#	This setting controls the task library creation behavior
#
USE_TLL=true; export USE_TLL

#
#	This setting determines if TMA (LCF endpoints) are supported in this install)
#
TMA_ENABLED=true
if wlookup -ar Gateway > /dev/null 2>& 1; then
  :
else
  echo "Dataless endpoints are not supported by this version of Tivoli" >& 2
  TMA_ENABLED=false
fi
export TMA_ENABLED

#
#       Use the MODULE setting to determine the patch id (for uninstall)
#
PATCH_ID=Secureway; export PATCH_ID

#
#	Use the module-level TaskRoles setting to set up a default ROLE for tasks
#
DEFAULT_TASKROLES=super; export DEFAULT_TASKROLES

#
#	Debugging code: by creating a directory called .plusdebug in
#		the appropriate TEMP directory, the output of scripts is
#		redirected to a file in TEMP by the same name as the script.
#
TEMP=/tmp
if [ x"$OS" = x"Windows_NT" ]; then
	TEMP=$DBDIR/tmp
else
	TEMP=/tmp
fi

DEBUGDIR=$TEMP/.plusdebug

SCRIPTNAME=`echo $0 | tr "\\\\\\\\" "/"`
SCRIPTNAME=`basename $SCRIPTNAME`

[ -d "$DEBUGDIR" ] && exec > $DEBUGDIR/$SCRIPTNAME && DEBUG=true && set -xv
[ -f "$DEBUGDIR" ] && DEBUG=true && set -xv

chmod +x $LINKDIR/Link.install $LINKDIR/Link.init $LINKDIR/Link.cfg $LINKDIR/w* $LINKDIR/cfgappicon $LINKDIR/faux* $LINKDIR/*.sh
if $UNDO; then
  ## use existing undo interface to PLUSinstruct.sh ...
  $LINKDIR/PLUSinstruct.sh -ud${UNINSTALL_OPTS} ./PLUSproduct-info.sh

else
  ## do install
  . $LINKDIR/PLUSinstall.sh

  ###########################################################################
  #
  #  at this point the plus module has been installed.
  #  insert any code to run after installation here.
  #

fi

custom_tasks()
{

  if [ ! -d $BINDIR/../lcf_bundle/secureway ] ; then
    mkdir $BINDIR/../lcf_bundle/secureway
  fi
 
  wdepset -c secureway_deps -a aix4-r1 secureway/startp  \
  +a +p %TOOLS% -a w32-ix86 secureway/reg2.exe \
  +a +p %TOOLS% -a aix4-r1 secureway/fwLogfile.conf \
  +a +p %TOOLS% -a w32-ix86 secureway/fwLogfile.conf \
  +a +p %TOOLS% -a aix4-r1 secureway/fwLogfile.map \
  +a +p %TOOLS% -a w32-ix86 secureway/fwLogfile.map \
  +a +p %TOOLS% -a aix4-r1 secureway/eofFile.dne \
  +a +p %TOOLS% -a w32-ix86 secureway/eofFile.dne \
  +a +p %TOOLS% -a aix4-r1 secureway/fwLogfile.pl \
  +a +p %TOOLS% -a w32-ix86 secureway/fwLogfile.pl \
  +a +p %TOOLS% -a aix4-r1 secureway/system.config \
  +a +p %TOOLS% -a w32-ix86 secureway/system.config \
  +a +p %TOOLS% -a w32-ix86 bin/w32-ix86/bin/postemsg.exe \
  +a +p %TOOLS% -a w32-ix86 secureway/startp.exe \
  +a +p %TOOLS% -a w32-ix86 secureway/reg.exe \
  +a +p %TOOLS% -a w32-ix86 secureway/servMgr.exe \
  +a +p %TOOLS% -a w32-ix86 secureway/srvany.exe \
  +a +p %TOOLS% -a w32-ix86 secureway/mkserv.bat \
  +a +p %TOOLS% -a aix4-r1 bin/aix4-r1/bin/postemsg \
  +a +p %TOOLS% -a w32-ix86 secureway/Logfile.pl \
  +a +p %TOOLS% -a aix4-r1 secureway/Logfile.pl \
  +a +p %TOOLS% -a w32-ix86 secureway/tec.pl \
  +a +p %TOOLS% -a aix4-r1 secureway/tec.pl \
  +a +p %TOOLS% -a w32-ix86 secureway/trace.pl \
  +a +p %TOOLS% -a aix4-r1 secureway/trace.pl \
  +a +p %TOOLS% -a w32-ix86 secureway/fwLogfile.conf \
  +a +p %TOOLS% -a aix4-r1 secureway/fwLogfile.conf \
  +a +p %TOOLS% -a w32-ix86 secureway/post.cfg \
  +a +p %TOOLS% -a aix4-r1 secureway/post.cfg \
  +a +p %TOOLS% -a aix4-r1 secureway/getopts.pl \
  +a +p %TOOLS% -a aix4-r1 secureway/install.cfg \
  +a +p %TOOLS% -a aix4-r1 secureway/install.pl \
  +a +p %TOOLS% -a aix4-r1 secureway/readConfigFile.pl \
  +a +p %TOOLS% -a aix4-r1 secureway/updateAixSysFiles.pl \
  +a +p %TOOLS% -a aix4-r1 secureway/updateConfig.pl \
  +a +p %TOOLS% -a w32-ix86 secureway/updateConfig.pl +a +p %TOOLS%

  sleep 3

  PLUS_DIR="$BINDIR/../generic_unix/TME/PLUS/SECUREWAY_FIREWALL"
  BUNDLE="$BINDIR/../lcf_bundle/secureway"
  if [ -d "$BINDIR/../lcf_bundle" ] ; then
 
    cp $PLUS_DIR/startp $BUNDLE 
    cp $PLUS_DIR/reg2.exe $BUNDLE

    cp $PLUS_DIR/fwLogfile.conf $BUNDLE
    cp $PLUS_DIR/fwLogfile.map $BUNDLE
    cp $PLUS_DIR/fwLogfile.trace $BUNDLE
    cp $PLUS_DIR/fwLogfile.bat $BUNDLE
    cp $PLUS_DIR/eofFile.dne $BUNDLE
    cp $PLUS_DIR/fwLogfile.pl $BUNDLE
    cp $PLUS_DIR/mkserv.bat $BUNDLE
    cp $PLUS_DIR/post.cfg $BUNDLE
    cp $PLUS_DIR/startp.exe $BUNDLE
    cp $PLUS_DIR/system.config $BUNDLE
    cp $PLUS_DIR/Logfile.pl $BUNDLE
    cp $PLUS_DIR/tec.pl $BUNDLE
    cp $PLUS_DIR/trace.pl $BUNDLE
    cp $PLUS_DIR/reg.exe $BUNDLE
    cp $PLUS_DIR/servMgr.exe $BUNDLE
    cp $PLUS_DIR/srvany.exe $BUNDLE
    cp $PLUS_DIR/getopts.pl $BUNDLE
    cp $PLUS_DIR/install.cfg $BUNDLE
    cp $PLUS_DIR/install.pl $BUNDLE
    cp $PLUS_DIR/readConfigFile.pl $BUNDLE
    cp $PLUS_DIR/updateAixSysFiles.pl $BUNDLE
    cp $PLUS_DIR/updateConfig.pl $BUNDLE

  fi
 
  wdepset -c all_secureway_deps -a depset @DependencyMgr:TMB_ROOT_task \
   -a depset @DependencyMgr:secureway_deps 

  sleep 3

  wchdep @Classes:TaskEndpoint @DependencyMgr:all_secureway_deps run_task

}

delete_custom_filepacks()
{
  # uninstall custom filepacks
  FP=`wls -ld /Library/FilePackage | awk '{print $1}'`
  MEMBERS=`objcall $FP _get_members`
  for i in `echo $MEMBERS`
  do
    LABEL=`idlattr -tg $i label string | cut -d '"' -f2`
    case $LABEL in SECUREWAY_FIREWALL_Client_after_aix | \
                   SECUREWAY_FIREWALL_Client_install_aix  | \
                   SECUREWAY_FIREWALL_Client_after | \
                   SECUREWAY_FIREWALL_Client_install* )
                   objcall $i o_rmobj
                   ;;
    esac
  done
  DMC=`wlookup -ar FilePackage | grep SECUREWAY | awk '{print $1}'`
  for i in `echo $DMC`
  do
    wregister -u -r FilePackage "$i"
  done
}

delete_tasks()
{
  wchdep @Classes:TaskEndpoint @DependencyMgr:TMB_ROOT_task run_task
  wdepset -d @DependencyMgr:secureway_deps
  wdepset -d @DependencyMgr:all_secureway_deps
  rm -rf $BINDIR/../lcf_bundle/secureway
}

delete_all()
{

  SOL=`wls -ld /Library/SolutionsLink | awk '{print $1}'`
  SOLS=`wls -l /Library/SolutionsLink | grep Firewall | awk '{print $1}'`
  for i in `echo $SOLS`
  do
        objcall $SOL _remove_object $i
        objcall $i o_rmobj
  done
  # back out profile managers; toolkit doesn't by default for
  # some reason
  PROF=`wls -l /Library/ProfileManager |grep "Firewall Servers" | awk '{print $1}'`
  if [ x"$PROF" != x ]; then
    idlattr -ts $PROF subscribers TMF_Types::ObjectList '{ 0 }'
    idlcall $PROF remove
  fi
  PROF=`wls -l /Library/ProfileManager |grep "Firewall HTTP Proxy Servers" | awk '{print $1}'`
  if [ x"$PROF" != x ]; then
    idlattr -ts $PROF subscribers TMF_Types::ObjectList '{ 0 }'
    idlcall $PROF remove
  fi
  PROF=`wls -l /Library/ProfileManager |grep "Firewall Configuration Clients" | awk '{print $1}'`
  if [ x"$PROF" != x ]; then
    idlattr -ts $PROF subscribers TMF_Types::ObjectList '{ 0 }'
    idlcall $PROF remove
  fi

  # back out top level collection icon
  tl=`wls -l /Library/imp_TMF_TGC::CollectionGUI | grep \
   "SecureWay Firewall Plus for Tivoli" | awk '{print $1}'`
  idlcall $tl remove

  # back out presentation region
  PRES=`wls -l /Library/Presentation | grep "SecureWay Firewall Plus for Tivoli" | awk '{print $1}'`
  PRS=`wls -ld /Library/Presentation | awk '{print $1}'`
  for obj in `echo $PRES`
  do
    objcall $PRS _remove_object $obj
    objcall $obj o_rmobj
  done
 
}
 
if [ $UNINSTALL -eq 1 ]; then
  if [ $DOALL -eq 1 ]; then
    delete_custom_filepacks
    delete_tasks
    delete_all
  else
    if [ x"$DO_JOBS" = x"true" ] ; then
      delete_tasks
    fi
    if [ x"$DO_FILEPACKS" = x"true" ] ; then
      delete_custom_filepacks
    fi
    if [ x"$DO_JOBS" = x"true" ] && [ x"$DO_FILEPACKS" = x"true" ] \
     && [ x"$DO_SENTRIES" = x"true" ] ; then
      delete_all
    fi
  fi
else
  if [ $DOALL -eq 1 ]; then
    # custom_filepacks
    custom_tasks
    # custom_monitors
  else
    if [ x"$DO_JOBS" = x"true" ] ; then
      custom_tasks
    fi
    # if [ x"$DO_FILEPACKS" = x"true" ] ; then
    #  custom_filepacks
    # fi
    # if [ x"$DO_SENTRIES" = x"true" ] ; then
    #  custom_monitors
    # fi
  fi
  FWSERVER=`$BINDIR/../generic_unix/TME/PLUS/SECUREWAY_FIREWALL/get_fw_server.sh`
  FWHTTPSERVER=`$BINDIR/../generic_unix/TME/PLUS/SECUREWAY_FIREWALL/get_fwhttp_server.sh`
  if [ x"$FWSERVER" != x"$MNNAME" ]; then
    wunsub @ProfileManager:"Firewall Servers#$IRONAME" @ManagedNode:"$MNNAME"
  fi
  if [ x"$FWHTTPSERVER" != x"$MNNAME" ]; then
    wunsub @ProfileManager:"Firewall HTTP Proxy Servers#$IRONAME" @ManagedNode:"$MNNAME"
  fi
fi

exit 0

