#!/etc/Tivoli/bin/perl
# -- BEGIN COPYRIGHT --
# IBM SecureWay Firewall Version 4.1
# Licensed Materials - Property of IBM
#
# 5697-F48
#
# (C) Copyright IBM Corp. 1985, 1994, 1999 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -- END COPYRIGHT --

#
# Component Name: Logfile Adapter 
#
# Program: readConfigFile.pl
#

# --------------------------------------------------------------------------
# Function: readConfigFile()
#
# Description: Read the config file and set some variables
# --------------------------------------------------------------------------

sub readConfigFile
{
  local($configFile, *srcDir, *sCfgDir, *binDir, *configDir, *PERL_LOC, *owner,
		*overRight, *updateSys) = @_;
  local($attrib, $value);

  if ($configFile eq "") { return; }

# print "Reading configuration file: $configFile\n";

  if (!open(CF, "< $configFile"))
  {
    print "readConfigFile: can't open config file $configFile\n";
    return;
  }

  while (<CF>)
  {
    next if (/^#/);		# skip comments
    next if (/^$/);		# skip empty lines
    next if (/^[ \t]/);		# skip lines with white space
    next if (! /=/);		# Don't scan lines w/o a variable assignment.

    $_ =~ (/([^=]+)=(.*)$/);	# parse the attrib = value line

    $attrib = $1;
    $value  = $2;

    $attrib =~ tr/A-Z/a-z/;	# convert 'attrib' to lower case
    $attrib =~ s/[ \t]//g;	# strip all white space from 'attrib'
    $value  =~ s/[ \t]//g;	# strip all white space from 'value'

    if ($attrib eq "srcbindir"  && $srcDir     eq "") { $srcDir     = $value; }
    if ($attrib eq "srccfgdir"  && $sCfgDir    eq "") { $sCfgDir    = $value; }
    if ($attrib eq "bindir"     && $binDir     eq "") { $binDir     = $value; }
    if ($attrib eq "configdir"  && $configDir  eq "") { $configDir  = $value; }
    if ($attrib eq "owner"      && $owner      eq "") { $owner      = $value; }
    if ($attrib eq "perl_loc"   && $PERL_LOC   eq "") { $PERL_LOC   = $value; }
    if ($attrib eq "overright"  && $overRight  eq "")
    {
      if ($value eq "n" || $value eq "N" || $value eq "0")
      {
        $overRight = 0;
      }
      else
      {
        $overRight = 1;
      }
    }

    if ($attrib eq "update"  && $updateSys  eq "")
    {
      if ($value eq "n" || $value eq "N" || $value eq "0")
      {
        $updateSys = 0;
      }
      else
      {
        $updateSys = 1;
      }
    }

    # Note: The DEBUG variable is global. It didn't seem to make sense
    #       passing it all over the place.

    if ($attrib eq "debug"      && $DEBUG      eq "") { $DEBUG      = $value; }
  }

  close(CF);

  return;
}

1;	# must be here so require() will not fail!!
