#!/etc/Tivoli/bin/perl
# -- BEGIN COPYRIGHT --
# IBM SecureWay Firewall Version 4.1
# Licensed Materials - Property of IBM
#
# 5697-F48
#
# (C) Copyright IBM Corp. 1985, 1994, 1999 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -- END COPYRIGHT --

#
# Program: updateAixSysFiles.pl
#

$configFile = "/etc/rc.nfs";		# AIX sys file to update

# --------------------------------------------------------------------------
# Function: bailOnError()
# --------------------------------------------------------------------------
 
sub bailFromAIX
{
  local($msg, $PERL_LOC) = @_;
 
  $bailMsg = $msg;
  return(1);
}

# --------------------------------------------------------------------------
# Function: traceAIX()
# --------------------------------------------------------------------------

sub traceAIX
{
  local($msg) = @_;

  if ($TRACEON != 0) { print "$msg"; }
}

# --------------------------------------------------------------------------
# Function: copySysFile()
# --------------------------------------------------------------------------

sub copySysFile
{
  local($sysConfigFile, *backupSysConfigFile) = @_;
  local($cmd);
  local($sec, $min, $hr, $mday, $mon, $yr, $wday, $yday, $isdst);
  local($mon);
  local($rc);

  @mon  = ("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep",
		"Oct", "Nov", "Dec");

  ($sec, $min, $hr, $mday, $mon, $yr, $wday, $yday, $isdst) =
	localtime(time);

  $backupSysConfigFile = "$sysConfigFile.@mon[$mon]_$mday,$hr:$min:$sec";
  $cmd = "cp $sysConfigFile $backupSysConfigFile";

  $rc = system($cmd);

  &traceAIX("making backup of $sysConfigFile called $backupSysConfigFile\n");

  return($rc);
}

# --------------------------------------------------------------------------
# Function: addLines()
#
# Description: 
# --------------------------------------------------------------------------

sub addLines
{
  local($etcDir) = @_;

  print CFnew "\n";
  print CFnew "#\n";
  print CFnew "# start SecureWay Plus for Tivoli logfile adapter\n";
  print CFnew "#\n";
  print CFnew "\n";
  print CFnew "if [ -f $etcDir/fwLogfile.pl ]; then\n";
  print CFnew "  ADAPTER_HOME=$etcDir\n";
  print CFnew "  export ADAPTER_HOME\n";
  print CFnew "  $PERL_LOC $etcDir/fwLogfile.pl\n";
  print CFnew "  echo \"SecureWay Plus for Tivoli logfile adapter started.\"\n";
  print CFnew "fi\n";
}

# --------------------------------------------------------------------------
# Function: updateAixConfigFile()
#
# Description: Check if the MasterCell Server process
# --------------------------------------------------------------------------

sub updateAixConfigFile
{
  local($binDir, $etcDir) = @_;
  local($ln);
  local($lookFor, $hit);
  local($offset, $ind);

  &copySysFile($configFile, *backupConfigFile);

  if (!open(CF, "< $backupConfigFile"))
  {
    &traceAIX("updateSysFile: can't open config file $backupConfigFile\n");
    return(1);
  }

  if (!open(CFnew, "> $configFile"))
  {
    &traceAIX("updateSysFile: can't open config file $configFile\n");
    return(1);
  }

  $lookFor = "$PROD.sh";

  $hit = 0;
  while ($ln = <CF>)
  {
    $offset = index($ln, "#");

    if (index($ln, "start SecureWay Plus for Tivoli logfile adapter") > 0) { next; }

    if ($ind = index($ln, "$lookFor ]; then") > 0 &&
       ($offset < 0 || $offset > $ind))
    { $hit = 1; }

    if ($ind = index($ln, "fi") >= 0 && $hit == 1 &&
       ($offset < 0 || $offset > $ind))
    { $hit = 2; }

    if ($hit == 1) { next; }
    if ($hit == 2) { $hit++; next; }

    print CFnew $ln;

    if ($hit == 3) { $hit = 0; }
  }

  close(CF);

  &addLines($etcDir);

  close(CFnew);

  return;
}

# --------------------------------------------------------------------------
# Function: updateAixSysFiles()
#
# Description: Check if the MasterCell Server process
# --------------------------------------------------------------------------

sub updateAixSysFiles
{
  local($passInterp, $passPROD, $passTRACE, $binDir, $etcDir) = @_;
  local($rc);

  $interp  = $passInterp;
  $PROD    = $passPROD;
  $TRACEON = $passTRACE;

  &bailFromAIX("wrong interp type for AIX: $interp") if ($interp ne "aix");
  &bailFromAIX("system file $configFile does not exist\n") if ! -f $configFile;

  &traceAIX("updating AIX system file: $configFile\n");

  $rc = &updateAixConfigFile($binDir, $etcDir);

  &traceAIX("done with update.\n");

  return($rc);
}

# --------------------------------------------------------------------------
# Function: main()
# --------------------------------------------------------------------------

# &updateAixSysFiles("aix", "itcell", 1, "/tmp/mcell", "/etc/itc");

# --------------------------------------------------------------------------

1;	# must be here so require() will not fail!!
