#!/etc/Tivoli/bin/perl
# -- BEGIN COPYRIGHT --
# IBM SecureWay Firewall Version 4.1
# Licensed Materials - Property of IBM
#
# 5697-F48
#
# (C) Copyright IBM Corp. 1985, 1994, 1999 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -- END COPYRIGHT --

#
# Program: updateConfig.pl
#
# Description: This program is used to update the config file.
#

# -------------------------------------------------------------------------
# function: usage
# -------------------------------------------------------------------------

sub usage
{
  print "$0: configFile attribute value\n\n";
  print "This program is used to replace a value in the provided\n";
  print "configuration file or append a new 'attribute = value' pair\n";
  print "to the configuration file.\n\n";
  print "If attribute exists then its value will be replaced\n";
  print "otherwise, a new 'attribute = value' pair will be appended\n";
  print "to the file.\n\n";
  print "Note: the original configuration file will be renamed as:\n\n";
  print "      mv filename.cfg -> filename.cfg.timestamp\n\n";
  print "where timestamp is the time when the command was run.\n";
  print "\n";
  print "usage $0 configFile attribute value\n";

  exit(1);
}

# -------------------------------------------------------------------------
# function: parseCmdLine
#
# description:
# -------------------------------------------------------------------------
sub parseCmdLine
{
  local(*configFile, *attrib, *value) = @_;

  if ($#ARGV != 2) { &usage(); };

  $configFile = $ARGV[0];
  $attrib     = $ARGV[1];
  $value      = $ARGV[2];

  if ($configFile eq "-h") { &usage(); }
}

# -------------------------------------------------------------------------
# function: addLine
#
# description:
# -------------------------------------------------------------------------
sub addLine
{
  local($line) = @_;

  print OUT_HANDLE $line;
# print $line;
}

# -------------------------------------------------------------------------
# function: getFileExtension
# -------------------------------------------------------------------------
sub getFileExtension
{
  local($name, *ext) = @_;

  $ext = "";

  while (($n = index($name, "/")) >= 0) { $name = substr($name, $n + 1); }

  if (($n = index($name, ".")) >= 0)
  { 
    $ext = substr($name, $n + 1);
    $ext =~ tr/A-Z/a-z/;	# convert 'ext' to lower case
  }

  # print "ext: $ext";
}

# -------------------------------------------------------------------------
# function: processFile
#
# description:
# -------------------------------------------------------------------------
sub processFile
{
  local($filename, $attrib, $value, $addEOL) = @_;
  local($rc, $tempFile, $timeStamp);
  local($low_attrib, $cases_cur_attrib, $cur_attrib, $cur_alue);
  local($matched);

  $low_attrib = $attrib;
  $low_attrib =~ tr/A-Z/a-z/;		# convert 'attrib' to lower case

# ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
#
# if (length($sec)  < 2) { $sec  = "0$sec" };
# if (length($min)  < 2) { $min  = "0$min" };
# if (length($hour) < 2) { $hour = "0$hour" };
# if (length($mday) < 2) { $mday = "0$mday" };
# if (length($mon)  < 2) { $mon  = "0$mon" };
# if (length($year) < 2) { $year = "0$year" };
#
# $timeStamp = "$hour:$min:$sec $mon/$mday/$year";

  $timeStamp = time;
  $tempFile  = "$filename$timeStamp.tmp";

  open(IN_HANDLE,  $filename) || die "Can't open config file: $filename\n";
  open(OUT_HANDLE, "> $tempFile") || die "Can't open tempfile: $tempFile\n";

  $matched = 0;

  while (<IN_HANDLE>)
  {
    if ($_ =~ /^#/)		# copy over comments
    {
      &addLine($_);
      next;
    }

    if ($_ =~ /^[ \t]/ || $_ =~ /^$/)	# white space or null line
    {
      &addLine($_);
      next;
    }

    if (!($_ =~ /=/))		# skip lines that don't contain an '='
    {
      &addLine($_);
      next;
    }

    $_ =~ (/([^=]+)=(.*)$/);    # parse the attrib = value line

    $cased_cur_attrib = $1;

    $cur_attrib = $1;
    $cur_value  = $2;

    $cur_attrib =~ s/[ \t]*$//;		# strip all white space from 'attrib'
    $cur_attrib =~ tr/A-Z/a-z/;		# convert 'attrib' to lower case

#   print "ca: [$cur_attrib]\n";
#   print "la: [$low_attrib]\n";

    if ($cur_attrib eq $low_attrib)
    {
      &addLine("$cased_cur_attrib=$value$addEOL\n");
      $matched = 1;

#     print "attribute '$attrib' has been updated to '$value'\n";

      next;
    }
    
    # didn't match any conditions so copy it and move on

    &addLine($_);
  }			# end while()

  if ($matched == 0)	# no match, so append
  {
    &addLine("$attrib=$value$addEOL\n");
#   print "'$attrib = $value' has been added\n";
  }

  close(IN_HANDLE);
  close(OUT_HANDLE);

  # -----------------------------------------------------------
  # Ok, we now have the new file created rename the original
  # and copy in the new one.
  # -----------------------------------------------------------

# system("mv $filename $filename.$timeStamp");
  system("mv $tempFile $filename");
}

# -------------------------------------------------------------------------
# main()
# -------------------------------------------------------------------------

$ignoreCaseFlag = 0;

&parseCmdLine(*configFile, *attrib, *value);

# print "config file: $configFile\n";
# print "attribute  : $attrib\n";
# print "value      : $value\n";

&getFileExtension($configFile, *ext);

if ($ext eq "bat" || $ext eq "cmd" || $ext eq "rsp") { $addEOL = "\r"; }
else                                                 { $addEOL = ""; }

# print "Updating/adding attribute/value pair '$attrib = $value'\n";
# print "in configuration file: $configFile\n\n";

&processFile($configFile, $attrib, $value, $addEOL);

# print "Done.\n";
